@@ -151,16 +151,23 @@ class LupusecAPI:
             return {}
 
 
-    async def _async_api_post(ip, session, action_url, params) -> Dict:
+    async def _async_api_post(ip, session, action_url, headers, params) -> Dict:
         """Generic sync method to call the Lupusec API"""
         # Generate complete URL from Constants.py
         url = f'{CONST.URL_HTTP}{ip}{CONST.URL_PORT}{CONST.URL_ACTION}{action_url}'
         _LOGGER.debug("_async_api_post() called: URL=%s", url)
         start_time = time.time()
         _LOGGER.debug(f"Starttime: {start_time}")
+        if (headers == None):
+            headers = {}
+        print("_async_api_post() called...")
+        print("headers:")
+        print(headers)
+        print("params:")
+        print(params)
 
         try:
-            async with session.post(url, data=params, ssl=False) as resp:
+            async with session.post(url, headers=headers, data=params, ssl=False) as resp:
                 # check for Response Status other than 200
                 _LOGGER.debug("Response_Status=%s", resp.status)
                 if resp.status != 200:
@@ -181,6 +188,7 @@ class LupusecAPI:
                 # ToDo: check for empty body, size = 0
                 content = content.replace(chr(245), "")
                 content = content.replace("\t", "")
+                print(content)
                 clean_content = json.loads(content)
                 _LOGGER.debug("Data Type of Response: =%s", type(clean_content))
                 end_time = time.time()
@@ -285,30 +293,93 @@ class LupusecAPI:
         _LOGGER.debug("__init__.py.async_set_mode() finished.")
 
 
-    def get_power_switches(self):
-        _LOGGER.debug("get_power_switches() called:")
-        stampNow = time.time()
-        length = len(self._devices)
-        if self._cachePss is None or stampNow - self._cacheStampP > 2.0:
-            self._cacheStamp_p = stampNow
-            response = self._request_get("pssStatusGet")
-            response = self.clean_json(response.text)["forms"]
-            powerSwitches = []
-            counter = 1
-            for pss in response:
-                powerSwitch = {}
-                if response[pss]["ready"] == 1:
-                    powerSwitch["status"] = response[pss]["pssonoff"]
-                    powerSwitch["device_id"] = counter + length
-                    powerSwitch["type"] = CONST.TYPE_POWER_SWITCH
-                    powerSwitch["name"] = response[pss]["name"]
-                    powerSwitches.append(powerSwitch)
-                else:
-                    _LOGGER.debug("Pss skipped, not active")
-                counter += 1
-            self._cachePss = powerSwitches
+    async def async_set_switch(self, switch, mode) -> None:
+        """Async method to set switches."""
+        _LOGGER.debug("__init__.py.async_set_switch() called: ")
+        _LOGGER.info("...for switch: %s, set mode: %s", switch, mode)
+        execution = "a=1&z=" + str(switch) + "&sw=" + mode + "&pd="
+        # example: exec: a=1&z=20&sw=on&pd=
+        _LOGGER.debug("{ exec: %s}", execution)        
+        params = {"exec": execution}
+        print(params)
 
-        return self._cachePss
+         # Control Switch
+        async with aiohttp.ClientSession(auth=self._auth) as session:
+            _LOGGER.debug("auth.encode: %s", self._auth.encode())            
+
+            # Get Session Token
+            _LOGGER.debug("__init__.py.async_set_switch(): REQUEST=%s", CONST.TOKEN_REQUEST)
+            token_response = await LupusecAPI.async_get_token(self, session)
+            _LOGGER.debug("async_get_token(): done. check response...")
+            print(token_response)
+            if (token_response != 0):
+                _LOGGER.debug("Token: %s", self._token)
+                headers = {"X-Token": self._token}
+                print(headers)
+
+                # SET_SWITCH
+                _LOGGER.debug("__init__.py.async_set_switch(): REQUEST=%s", CONST.EXECUTE_REQUEST)
+                set_switch_response = await LupusecAPI._async_api_post(self._ip_address, session, 
+                    CONST.EXECUTE_REQUEST, headers, params)
+                _LOGGER.debug("_async_api_post(): done. check response...")
+
+                if (sys.getsizeof(set_switch_response) > 0):
+                    _LOGGER.debug("RESULT_RESPONSE: %s", set_switch_response[CONST.RESPONSE_RESULT]) 
+                    if (token_response[CONST.RESPONSE_RESULT] == 1):
+                        _LOGGER.debug("RESPONSE_MESSAGE: %s", set_switch_response[CONST.RESPONSE_MESSAGE]) 
+                        if (len(set_switch_response[CONST.RESPONSE_MESSAGE]) != 0):
+                            _LOGGER.info("...switch: %s, set to mode: %s", switch, mode)
+                    else :
+                        _LOGGER.info("ERROR: RESULT_RESPONSE: %s", set_switch_response[CONST.RESPONSE_RESULT])
+                        _LOGGER.info("RESPONSE_MESSAGE: %s", set_switch_response[CONST.RESPONSE_MESSAGE])  
+            else :    
+                _LOGGER.info("ERROR: no session Token available.")
+            
+        _LOGGER.debug("__init__.py.async_set_switch() finished.")
+
+
+    async def get_switches(self) -> Dict:
+        """Async method to get switches."""
+        _LOGGER.debug("__init__.py.get_switches() called: ")
+        timeNow = time.time()
+        length = len(self._devices)
+        
+        # Get switches from cache or update from Lupusec System
+        # ToDo: update frequency shall not be hard-coded -> transfer to constant
+        if self._cacheSwitches is None or timeNow - self._cacheStampP > 2.0:
+            _LOGGER.debug("...switches need update from Lupusec System.")
+            self._cacheStamp_p = timeNow
+
+            async with aiohttp.ClientSession(auth=self._auth) as session:
+                _LOGGER.debug("auth.encode: %s", self._auth.encode())  
+
+                # Get all devices and filter for switches
+                _LOGGER.debug("__init__.py.async_get_devices(): REQUEST=%s", CONST.DEVICE_LIST_REQUEST)
+                get_switches_response = await LupusecAPI._async_api_call(self._ip_address, session, CONST.DEVICE_LIST_REQUEST)
+                _LOGGER.debug("_async_api_call(): done. check response...")
+                for content in get_switches_response:
+                    # Retreive Device Liste from Response
+                    if CONST.DEVICE_LIST_HEADER in content:
+                        device_content = content[CONST.DEVICE_LIST_HEADER]
+                        print("Number of devices=", len(device_content))    
+                        if (len(device_content) != 0)                
+                            switches = []
+                            for device in device_content:
+                                print("sid: ", device["sid"], ", name: ", device["name"], 
+                                    ", type: ", device["type"], ", status: ", device["status"])
+                                if (type_tag in CONST.TYPES_SWITCH):    
+                                    switches.append(device)
+                                    _LOGGER.debug("device is switch...added.")
+                                else :
+                                    _LOGGER.debug("device is no switch...skipping.")
+                            self._cacheSwitches = switches
+                        else : 
+                            _LOGGER.info("ERROR: get_switches(): no switches found.")
+                    else :
+                        _LOGGER.info("ERROR: get_switches(): no switches found.")
+
+        _LOGGER.debug("__init__.py.get_switches() finished.")            
+        return self._cacheSwitches
 
 
     def get_sensors(self):
@@ -376,7 +447,6 @@ class LupusecAPI:
         return self._apiDevices
 
 
-
     def get_panel(self):
         _LOGGER.debug("get_panel() called:")
 	    # we are trimming the json from Lupusec heavily, since its bullcrap
